CountDownText class

CountDownText : A simple text widget that display the countdown timer based on the dateTime given e.g DateTime.utc(2050)

Inheritance

Constructors

CountDownText({Key? key, required DateTime? due, required String? finishedText, bool? longDateName = false, TextStyle? style, bool? showLabel = false, bool collapsing = false, String daysTextLong = " days ", String hoursTextLong = " hours ", String minutesTextLong = " minutes ", String secondsTextLong = " seconds ", String daysTextShort = " d ", String hoursTextShort = " h ", String minutesTextShort = " m ", String secondsTextShort = " s ", String endingText = ' left', VoidCallback? onFinished})

Properties

collapsing → bool
final
daysTextLong → String
final
daysTextShort → String
final
due → DateTime?
final
endingText → String
final
finishedText → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hoursTextLong → String
final
hoursTextShort → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
longDateName → bool?
final
minutesTextLong → String
final
minutesTextShort → String
final
onFinished → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondsTextLong → String
final
secondsTextShort → String
final
showLabel → bool?
final
style → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CountDownTextState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited